@@ -68,10 +68,35 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Use Perl code in distribution "resource" metadata
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 extends 'Dist::Zilla::Plugin::MetaResources';
-with 'Dist::Zilla::Role::TextTemplater';
+with 'Dist::Zilla::Role::TextTemplater' => { -version => '0.003' };
+
+# --------------------------------------------------------------------------------------------------
+
+#pod =Method BUILDARGS
+#pod
+#pod Parent's C<BUILDARGS> mangles all the arguments: it moves them into resources, including
+#pod C<TextTemplater> arguments: C<delimiters>, C<package>, C<prepend>. We have to protect
+#pod C<TextTemplater> arguments from being misinterpreted.
+#pod
+#pod =cut
+
+around BUILDARGS => sub {
+    my ( $orig, $class, $args ) = @_;
+    my $save = {};
+    for my $attr ( qw{ delimiters package prepend } ) {
+        if ( exists( $args->{ $attr } ) ) {
+            $save->{ $attr } = delete( $args->{ $attr } );
+        };
+    };
+    $args = $class->$orig( $args );
+    for my $attr ( keys( %$save ) ) {
+        $args->{ $attr } = $save->{ $attr };
+    };
+    return $args;
+};
 
 # --------------------------------------------------------------------------------------------------
 
@@ -149,7 +174,7 @@ Dist::Zilla::Plugin::MetaResources::Template - Use Perl code in distribution "re
 
 =head1 VERSION
 
-Version 0.002, released on 2015-07-15 10:42 UTC.
+Version 0.003, released on 2015-07-22 13:18 UTC.
 
 =head1 WHAT?
 
@@ -174,6 +199,14 @@ method, which expand templates in option values, all other work is done by the p
 
 Template processing abilities achieved by consuming C<Dist::Zilla::Role::TextTemplater> role.
 
+=head1 CLASS METHODS
+
+=head2 BUILDARGS
+
+Parent's C<BUILDARGS> mangles all the arguments: it moves them into resources, including
+C<TextTemplater> arguments: C<delimiters>, C<package>, C<prepend>. We have to protect
+C<TextTemplater> arguments from being misinterpreted.
+
 =head1 OBJECT METHODS
 
 =head2 BUILD
